copyWith abstract method

BaseModel copyWith(
  1. BaseModel? other, {
  2. bool merge = false,
})

Returns a new copy of the BaseModel with the fields updated from the other BaseModel. If merge is true, the fields are merged, otherwise they are replaced.

Implementation

BaseModel copyWith(BaseModel? other, {bool merge = false});