collectionPath property
String?
get
collectionPath
The collection path of the model for databases like Firestore.
Implementation
String? get collectionPath => this.collection?.join('/');
The collection path of the model for databases like Firestore.
String? get collectionPath => this.collection?.join('/');