docPath property
String
get
docPath
The document path of the model for databases like Firestore.
Implementation
String get docPath => this.doc.join('/');
The document path of the model for databases like Firestore.
String get docPath => this.doc.join('/');