Field class

Inheritance

Constructors

Field({List<String>? fieldPath, required dynamic fieldType, bool? nullable, Field? child})
const
Field.c2({List<String>? fieldPath, dynamic fieldType, bool? nullable, Field? child})
const
Field.c3({List<String>? fieldPath, dynamic fieldType, bool? nullable, Field? child})
factory
Field.from(BaseModel? other)
factory
Field.fromJson(Map<String, dynamic>? otherData)
factory
Field.fromJsonString(String source)
factory
Field.fromUri(Uri? uri)
factory
Field.of(Field other)
factory

Properties

$className String
The class name of the model as a string.
no setteroverride
child Field?
final
childField Field?
no setter
fieldPath List<String>?
final
fieldPathField List<String>?
no setter
fieldType → dynamic
final
fieldTypeCode String?
The type code of the field (the type with any special, characters, such as 'String?').
no setterinherited
fieldTypeField → dynamic
no setter
hashCode int
The hash code for this object.
no setterinherited
nullable bool?
final
nullableField bool?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toRecord TFieldRecord
Converts this to a TFieldRecord.
no setterinherited

Methods

copyWith(BaseModel? other) Field
Returns a new copy of the BaseModel with the fields updated from the other BaseModel.
override
equals(dynamic other) bool
Compares the BaseModel with another BaseModel using the DeepCollectionEquality and returns true if they are equal.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortedJson({dynamic defaultValue, bool includeNulls = false}) Map<String, dynamic>
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel, with the keys sorted alphabetically.
inherited
toJson({dynamic defaultValue, bool includeNulls = false}) Map<String, dynamic>
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel.
override
toJsonString() String
Returns a JSON string representation of the BaseModel.
inherited
toString() String
A string representation of this object.
inherited
toUrl() Uri
Converts the current BaseModel to a Uri that can be used as a distinct identifier. The model must not be too large to avoid exceeding the maximum length of a URL.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJsonOrNull(Map<String, dynamic>? otherData) Field?
fromJsonStringOrNull(String? source) Field?
fromOrNull(BaseModel? other) Field?
fromUriOrNull(Uri? uri) Field?
ofOrNull(Field? other) Field?

Constants

CLASS_NAME → const String