FieldUtils class final

Constructors

FieldUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fieldPathOrNull(dynamic unknown) List<String>?
Assumes unknown is a TFieldRecord or FieldModel or similar and tries to get the fieldPath property, or returns null.
fieldTypeOrNull(dynamic unknown) String?
Assumes unknown is a TFieldRecord or FieldModel or similar and tries to get the fieldType property, or returns null.
nullableOrNull(dynamic unknown) bool?
Assumes unknown is a TFieldRecord or FieldModel or similar and tries to get the nullable property, or returns null.
ofOrNull(dynamic unknown) FieldModel?
Assumes unknown is a TFieldRecord or FieldModel or similar and tries to construct a FieldModel, otherwise returns null.