Field class
Constructors
Field ({List <String > ? fieldPath , required dynamic fieldType , bool ? nullable , Field ? child })
const
Field.c2 ({List <String > ? fieldPath , dynamic fieldType , bool ? nullable , Field ? child })
const
Field.c3 ({List <String > ? fieldPath , dynamic fieldType , bool ? nullable , Field ? child })
factory
Field.from (BaseModel ? other )
factory
Field.fromJson (Map <String , dynamic > ? otherData )
factory
Field.fromJsonString (String source )
factory
Field.fromUri (Uri ? uri )
factory
Field.of (Field other )
factory
Methods
copyWith (BaseModel ? other )
→ Field
Returns a new copy of the BaseModel with the fields updated from the
other BaseModel.
override
equals (dynamic other )
→ bool
Compares the BaseModel with another BaseModel using the
DeepCollectionEquality and returns true if they are equal.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortedJson ({dynamic defaultValue , bool includeNulls = false })
→ Map <String , dynamic >
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel,
with the keys sorted alphabetically.
inherited
toJson ({dynamic defaultValue , bool includeNulls = false })
→ Map <String , dynamic >
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel.
override
toJsonString ()
→ String
Returns a JSON string representation of the BaseModel.
inherited
toString ()
→ String
A string representation of this object.
inherited
toUrl ()
→ Uri
Converts the current BaseModel to a Uri that can be used as a
distinct identifier. The model must not be too large to avoid exceeding
the maximum length of a URL.
inherited