FieldModel class

Inheritance

Constructors

FieldModel({List<String>? fieldPath, required dynamic fieldType, bool? nullable, FieldModel? child})
const
FieldModel.c2({List<String>? fieldPath, dynamic fieldType, bool? nullable, FieldModel? child})
const
FieldModel.c3({List<String>? fieldPath, dynamic fieldType, bool? nullable, FieldModel? child})
factory
FieldModel.from(BaseModel? other)
factory
FieldModel.fromJson(Map<String, dynamic>? otherData)
factory
FieldModel.fromJsonString(String source)
factory
FieldModel.fromUri(Uri? uri)
factory
FieldModel.of(FieldModel other)
factory

Properties

$className String
The class name of the model as a string.
no setteroverride
child FieldModel?
final
childField FieldModel?
no setter
fieldPath List<String>?
final
fieldPathField List<String>?
no setter
fieldType → dynamic
final
fieldTypeCode String?
The type code of the field (the type with any special, characters, such as 'String?').
no setterinherited
fieldTypeField → dynamic
no setter
hashCode int
The hash code for this object.
no setterinherited
nullable bool?
final
nullableField bool?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toRecord TFieldRecord
Converts this to a TFieldRecord.
no setterinherited

Methods

copyWith(BaseModel? other, {bool merge = false}) FieldModel
Returns a new copy of the BaseModel with the fields updated from the other BaseModel. If merge is true, the fields are merged, otherwise they are replaced.
override
equals(dynamic other) bool
Compares the BaseModel with another BaseModel using the DeepCollectionEquality and returns true if they are equal.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortedJson({bool includeNulls = false}) Map<String, dynamic>
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel, with the keys sorted alphabetically.
inherited
toJson({bool includeNulls = false}) Map<String, dynamic>
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel.
override
toJsonString() String
Returns a JSON string representation of the BaseModel.
inherited
toString() String
A string representation of this object.
inherited
toUrl() Uri
Converts the current BaseModel to a Uri that can be used as a distinct identifier. The model must not be too large to avoid exceeding the maximum length of a URL.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJsonOrNull(Map<String, dynamic>? otherData) FieldModel?
fromJsonStringOrNull(String? source) FieldModel?
fromOrNull(BaseModel? other) FieldModel?
fromUriOrNull(Uri? uri) FieldModel?
ofOrNull(FieldModel? other) FieldModel?

Constants

CLASS_NAME → const String