FieldUtils class final
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fieldPathOrNull(
dynamic unknown) → List< String> ? -
Assumes
unknownis a TFieldRecord or FieldModel or similar and tries to get thefieldPathproperty, or returnsnull. -
fieldTypeOrNull(
dynamic unknown) → String? -
Assumes
unknownis a TFieldRecord or FieldModel or similar and tries to get thefieldTypeproperty, or returnsnull. -
nullableOrNull(
dynamic unknown) → bool? -
Assumes
unknownis a TFieldRecord or FieldModel or similar and tries to get thenullableproperty, or returnsnull. -
ofOrNull(
dynamic unknown) → FieldModel? -
Assumes
unknownis a TFieldRecord or FieldModel or similar and tries to construct a FieldModel, otherwise returnsnull.