GenerateScreenBindings class
Constructors
-
GenerateScreenBindings({bool? isAccessibleOnlyIfLoggedInAndVerified, bool? isAccessibleOnlyIfLoggedIn, bool? isAccessibleOnlyIfLoggedOut, bool? isRedirectable, String? path, Set? internalParameters, Set? queryParameters, String? defaultTitle, String? makeup, String? className, String? screenKey})
-
const
-
GenerateScreenBindings.c2({bool? isAccessibleOnlyIfLoggedInAndVerified, bool? isAccessibleOnlyIfLoggedIn, bool? isAccessibleOnlyIfLoggedOut, bool? isRedirectable, String? path, Set? internalParameters, Set? queryParameters, String? defaultTitle, String? makeup, String? className, String? screenKey})
-
const
-
GenerateScreenBindings.c3({bool? isAccessibleOnlyIfLoggedInAndVerified, bool? isAccessibleOnlyIfLoggedIn, bool? isAccessibleOnlyIfLoggedOut, bool? isRedirectable, String? path, Set? internalParameters, Set? queryParameters, String? defaultTitle, String? makeup, String? className, String? screenKey})
-
factory
-
GenerateScreenBindings.from(BaseModel? other)
-
factory
-
GenerateScreenBindings.fromJson(Map<String, dynamic>? otherData)
-
factory
-
GenerateScreenBindings.fromJsonString(String source)
-
factory
-
GenerateScreenBindings.fromUri(Uri? uri)
-
factory
-
GenerateScreenBindings.of(GenerateScreenBindings other)
-
factory
Methods
-
copyWith(BaseModel? other)
→ GenerateScreenBindings
-
Returns a new copy of the BaseModel with the fields updated from the
other BaseModel.
override
-
equals(dynamic other)
→ bool
-
Compares the BaseModel with another BaseModel using the
DeepCollectionEquality and returns true if they are equal.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
sortedJson({dynamic defaultValue, bool includeNulls = false})
→ Map<String, dynamic>
-
Returns a Json i.e.
Map<String, dynamic> representation of the BaseModel,
with the keys sorted alphabetically.
inherited
-
toJson({dynamic defaultValue, bool includeNulls = false})
→ Map<String, dynamic>
-
Returns a Json i.e.
Map<String, dynamic> representation of the BaseModel.
override
-
toJsonString()
→ String
-
Returns a JSON string representation of the BaseModel.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
toUrl()
→ Uri
-
Converts the current BaseModel to a Uri that can be used as a
distinct identifier. The model must not be too large to avoid exceeding
the maximum length of a URL.
inherited