Property class
Constructors
-
Property({Map<
String, dynamic> ? options}) -
const
-
Property.c2({Map<
String, dynamic> ? options}) -
const
-
Property.c3({Map<
String, dynamic> ? options}) -
factory
- Property.from(BaseModel? other)
-
factory
-
Property.fromJson(Map<
String, dynamic> ? otherData) -
factory
- Property.fromJsonString(String source)
-
factory
- Property.fromUri(Uri? uri)
-
factory
- Property.of(Property other)
-
factory
Properties
- $className → String
-
The class name of the model as a string.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ Map<
String, dynamic> ? -
final
-
optionsField
→ Map<
String, dynamic> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
BaseModel? other) → Property -
Returns a new copy of the BaseModel with the fields updated from the
otherBaseModel.override -
equals(
dynamic other) → bool -
Compares the BaseModel with another BaseModel using the
DeepCollectionEqualityand returnstrueif they are equal.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sortedJson(
{dynamic defaultValue, bool includeNulls = false}) → Map< String, dynamic> -
Returns a Json i.e.
Map<String, dynamic>representation of the BaseModel, with the keys sorted alphabetically.inherited -
toJson(
{dynamic defaultValue, bool includeNulls = false}) → Map< String, dynamic> -
Returns a Json i.e.
Map<String, dynamic>representation of the BaseModel.override -
toJsonString(
) → String -
Returns a JSON string representation of the BaseModel.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toUrl(
) → Uri -
Converts the current BaseModel to a Uri that can be used as a
distinct identifier. The model must not be too large to avoid exceeding
the maximum length of a URL.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJsonOrNull(
Map< String, dynamic> ? otherData) → Property? -
fromJsonStringOrNull(
String? source) → Property? -
fromOrNull(
BaseModel? other) → Property? -
fromUriOrNull(
Uri? uri) → Property? -
ofOrNull(
Property? other) → Property?
Constants
- CLASS_NAME → const String