ModelJsScreen class
Constructors
ModelJsScreen ({int ? availHeight , int ? availWidth , int ? width , int ? height , String ? orientation , int ? colorDepth , int ? pixelDepth })
const
ModelJsScreen.c2 ({int ? availHeight , int ? availWidth , int ? width , int ? height , String ? orientation , int ? colorDepth , int ? pixelDepth })
const
ModelJsScreen.c3 ({int ? availHeight , int ? availWidth , int ? width , int ? height , String ? orientation , int ? colorDepth , int ? pixelDepth })
factory
ModelJsScreen.from (BaseModel ? other )
factory
ModelJsScreen.fromJson (Map <String , dynamic > ? otherData )
factory
ModelJsScreen.fromJsonString (String source )
factory
ModelJsScreen.fromUri (Uri ? uri )
factory
ModelJsScreen.of (ModelJsScreen other )
factory
Methods
copyWith (BaseModel ? other , {bool merge = false })
→ ModelJsScreen
Returns a new copy of the BaseModel with the fields updated from the
other BaseModel. If merge is true, the fields are merged, otherwise
they are replaced.
override
equals (dynamic other )
→ bool
Compares the BaseModel with another BaseModel using the
DeepCollectionEquality and returns true if they are equal.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortedJson ({bool includeNulls = false })
→ Map <String , dynamic >
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel,
with the keys sorted alphabetically.
inherited
toJson ({bool includeNulls = false })
→ Map <String , dynamic >
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel.
override
toJsonString ()
→ String
Returns a JSON string representation of the BaseModel.
inherited
toString ()
→ String
A string representation of this object.
inherited
toUrl ()
→ Uri
Converts the current BaseModel to a Uri that can be used as a
distinct identifier. The model must not be too large to avoid exceeding
the maximum length of a URL.
inherited